/*
 * Copyright (c) 1980 The Regents of the University of California.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *	This product includes software developed by the University of
 *	California, Berkeley and its contributors.
 * 4. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

char copyright[] =
"@(#) Copyright (c) 1980 The Regents of the University of California.\n"
"All rights reserved.\n";

/*
 * From: @(#)biff.c	5.3 (Berkeley) 6/1/90
 */
char rcsid[] = "$Id: biff.c,v 1.10 1999/09/28 22:29:27 netbug Exp $";

/*
 * biff
 */
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <sys/stat.h>
#include "../version.h"

int main(int argc, char *argv[])
{
  char *tty_ptr; /* Storage pointer to the stderr (fd 2) for tty */
  struct stat stb; /* Storage for return of stat on tty */
  
  /* ttyname() returns a pointer (tty_ptr) to the pathname of the
     terminal device that is open stderr. If this fails tell the
     user
  */
  
  if ((tty_ptr=ttyname(2))== NULL) /* 2 being the fd for stderr */
    {
      fprintf(stderr, "Failed to open stderr on your tty.\n");
      exit(1);
    }
  
  /* stat() the tty */
  
  if (stat(tty_ptr, &stb)== -1) /* ie stat returned an error */ 
    {
      perror(tty_ptr);
      exit(1);
    }
  
  /* If no command line arguments are specified then simply return
   the current status to the user
  */
  
  if (argc == 1) 
    {
      if(stb.st_mode&0100) /* if user execute bit is on (ie biff y) */
	{
	  printf("is y\n");
	}
      else
	{
	  printf("is n\n");
	}
    }
  
  /* If there's a command line argument... */
  
  else switch (argv[1][0]) /* switch based on argument */
    {
    case 'y': /* ie user entered biff y */
      if (chmod(tty_ptr, stb.st_mode|0100) == -1)
	perror(tty_ptr);
      break;
      
    case 'n': /* ie user entered biff n */
      if (chmod(tty_ptr, stb.st_mode&~0100) == -1)
	perror(tty_ptr);
      break;
      
    default: /* They used neither of the correct arguments -Doh! */
      fprintf(stderr, "usage: biff [y|n]\n");
    }

  return (stb.st_mode&0100) ? 0 : 1; /* Return 0 if on or 1 if off */
}
